==> ringcentral-widgets-0.12.0.tgz: package/components/CallingSettingsPanel/i18n/es-ES.ts <==
import callingOptions from 'ringcentral-integration/modules/CallingSettings/callingOptions';
export default {
  title: "Llamadas",
  [callingOptions.softphone]: "{brand}",
  [callingOptions.myphone]: "Mi teléfono {brand} ",
  [callingOptions.otherphone]: "Otro teléfono",
  [callingOptions.customphone]: "Personalizar teléfono",
  [callingOptions.browser]: "Navegador",
  [callingOptions.jupiter]: "{brand}",
  makeCallsWith: "Realizar mis llamadas con",
  ringoutHint: "Llamar primero a mi ubicación y conectar después con la parte que llama",
  myLocationLabel: "Mi ubicación",
  press1ToStartCallLabel: "Avisarme de que marque 1 para conectar la llamada",
  [`${callingOptions.browser}Tooltip`]: "Utilice esta opción para hacer y recibir llamadas con el micrófono y los altavoces de su equipo.",
  [`${callingOptions.softphone}Tooltip`]: "Utilice esta opción para hacer y recibir llamadas usando su {brand}.",
  [`${callingOptions.myphone}Tooltip`]: "Use esta opción para hacer llamadas usando su teléfono {brand}.",
  [`${callingOptions.myphone}Tooltip1`]: "En la llamada que realice, primero sonará su teléfono {brand} y luego el de la persona a la que llama.",
  [`${callingOptions.otherphone}Tooltip`]: "Utilice esta opción para realizar llamadas desde el resto de los teléfonos que ha añadido a su extensión {brand}, como el de su casa o el móvil.",
  [`${callingOptions.otherphone}Tooltip1`]: "En la llamada que realice, este teléfono sonará primero y luego el de la persona a la que llama.",
  [`${callingOptions.customphone}Tooltip`]: "Use esta opción para realizar llamadas usando el teléfono de su preferencia, introduciendo un número de teléfono válido en el campo que aparece a continuación.",
  [`${callingOptions.customphone}Tooltip1`]: "En la llamada que realice, este teléfono sonará primero y luego el de la persona a la que llama.",
  [`${callingOptions.jupiter}Tooltip`]: "Utilice esta opción para hacer y recibir llamadas usando su {brand}."
};

// @key: @#@"title"@#@ @source: @#@"Calling"@#@
// @key: @#@"[callingOptions.softphone]"@#@ @source: @#@"{brand}"@#@
// @key: @#@"[callingOptions.myphone]"@#@ @source: @#@"My {brand} Phone"@#@
// @key: @#@"[callingOptions.otherphone]"@#@ @source: @#@"Other Phone"@#@
// @key: @#@"[callingOptions.customphone]"@#@ @source: @#@"Custom Phone"@#@
// @key: @#@"[callingOptions.browser]"@#@ @source: @#@"Browser"@#@
// @key: @#@"[callingOptions.jupiter]"@#@ @source: @#@"{brand}"@#@
// @key: @#@"makeCallsWith"@#@ @source: @#@"Make my calls with"@#@
// @key: @#@"ringoutHint"@#@ @source: @#@"Ring me at my location first, then connect the called party"@#@
// @key: @#@"myLocationLabel"@#@ @source: @#@"My Location"@#@
// @key: @#@"press1ToStartCallLabel"@#@ @source: @#@"Prompt me to dial 1 before connecting the call"@#@
// @key: @#@"[`${callingOptions.browser}Tooltip`]"@#@ @source: @#@"Use this option to make and receive calls using your computer’s microphone and speaker."@#@
// @key: @#@"[`${callingOptions.softphone}Tooltip`]"@#@ @source: @#@"Use this option to make and receive calls using your {brand}."@#@
// @key: @#@"[`${callingOptions.myphone}Tooltip`]"@#@ @source: @#@"Use this option to make calls using your {brand} phone."@#@
// @key: @#@"[`${callingOptions.myphone}Tooltip1`]"@#@ @source: @#@"For the call you make, your {brand} phone will ring first then the party you called."@#@
// @key: @#@"[`${callingOptions.otherphone}Tooltip`]"@#@ @source: @#@"Use this option to make calls using your other phones such as home or cell phones that you have added in your {brand} Extension."@#@
// @key: @#@"[`${callingOptions.otherphone}Tooltip1`]"@#@ @source: @#@"For the call you make, this phone will ring first then the party you called."@#@
// @key: @#@"[`${callingOptions.customphone}Tooltip`]"@#@ @source: @#@"Use this option to make calls using any phone of your choice by entering a valid phone number in the field below."@#@
// @key: @#@"[`${callingOptions.customphone}Tooltip1`]"@#@ @source: @#@"For the call you make, this phone will ring first then the party you called."@#@
// @key: @#@"[`${callingOptions.jupiter}Tooltip`]"@#@ @source: @#@"Use this option to make and receive calls using your {brand}."@#@

==> ringcentral-widgets-0.13.0.tgz: package/components/CallingSettingsPanel/i18n/es-ES.ts <==
import callingOptions from 'ringcentral-integration/modules/CallingSettings/callingOptions';
export default {
  title: "Llamadas",
  [callingOptions.softphone]: "{brand} para escritorio",
  [callingOptions.browser]: "Navegador",
  [callingOptions.jupiter]: "{brand}",
  makeCallsWith: "Realizar mis llamadas con",
  ringoutHint: "Llamar primero a mi ubicación y conectar después con la parte que llama",
  myLocationLabel: "Mi ubicación",
  press1ToStartCallLabel: "Avisarme de que marque 1 para conectar la llamada",
  [`${callingOptions.browser}Tooltip`]: "Utilice esta opción para hacer y recibir llamadas con el micrófono y los altavoces de su equipo.",
  [`${callingOptions.softphone}Tooltip`]: "Utilice esta opción para hacer y recibir llamadas usando su {brand}.",
  [`${callingOptions.ringout}Tooltip`]: "Use esta opción para hacer llamadas con el número de teléfono seleccionado o introducido.",
  [`${callingOptions.ringout}Tooltip1`]: "Cuando haga una llamada, primero sonará este teléfono y, a continuación, la parte a la que llama.",
  [`${callingOptions.jupiter}Tooltip`]: "Utilice esta opción para hacer y recibir llamadas usando su {brand}."
};

// @key: @#@"title"@#@ @source: @#@"Calling"@#@
// @key: @#@"[callingOptions.softphone]"@#@ @source: @#@"{brand} for Desktop"@#@
// @key: @#@"[callingOptions.browser]"@#@ @source: @#@"Browser"@#@
// @key: @#@"[callingOptions.jupiter]"@#@ @source: @#@"{brand}"@#@
// @key: @#@"makeCallsWith"@#@ @source: @#@"Make my calls with"@#@
// @key: @#@"ringoutHint"@#@ @source: @#@"Ring me at my location first, then connect the called party"@#@
// @key: @#@"myLocationLabel"@#@ @source: @#@"My Location"@#@
// @key: @#@"press1ToStartCallLabel"@#@ @source: @#@"Prompt me to dial 1 before connecting the call"@#@
// @key: @#@"[`${callingOptions.browser}Tooltip`]"@#@ @source: @#@"Use this option to make and receive calls using your computer’s microphone and speaker."@#@
// @key: @#@"[`${callingOptions.softphone}Tooltip`]"@#@ @source: @#@"Use this option to make and receive calls using your {brand}."@#@
// @key: @#@"[`${callingOptions.ringout}Tooltip`]"@#@ @source: @#@"Use this option to make calls using your selected or entered phone number."@#@
// @key: @#@"[`${callingOptions.ringout}Tooltip1`]"@#@ @source: @#@"For the call you make, this phone will ring first then the party you called."@#@
// @key: @#@"[`${callingOptions.jupiter}Tooltip`]"@#@ @source: @#@"Use this option to make and receive calls using your {brand}."@#@
